const t=require("./chunk-BAUY9lu4.cjs");var n=t.__exportAll({createProgram:()=>r,default:()=>i,version:()=>e});function r(){throw new Error("TypeScript loader is not available in this build")}var e,i,u=t.__esmMin((()=>{e="0.0.0-stub",i={version:e,createProgram:r}}));Object.defineProperty(exports,"_stub_typescript_exports",{enumerable:!0,get:function(){return n}});Object.defineProperty(exports,"init__stub_typescript",{enumerable:!0,get:function(){return u}});
