import { n as a, r as s } from "./chunk-Njdj7H0c.js";
var o = /* @__PURE__ */ s({
  createProgram: () => t,
  default: () => e,
  version: () => r
});
function t() {
  throw new Error("TypeScript loader is not available in this build");
}
var r, e, _ = a((() => {
  r = "0.0.0-stub", e = {
    version: r,
    createProgram: t
  };
}));
export {
  _ as n,
  o as t
};
